/*
Import the spreadsheet rugby performance indicators example data.xlsx;
by double-clicking it in SAS Studio or running this import code, modified for your directory structure:
*/
FILENAME REFFILE '/folders/myshortcuts/ExternalFiles/Projects/Mixed-model Workshop/Generalized linear models/rugby performance indicators example data.xlsx';

PROC IMPORT DATAFILE=REFFILE
	DBMS=XLSX replace
	OUT=WORK.IMPORT;
	GETNAMES=YES;
RUN;

*proc print; run;

title "Simple stats";
proc means n nmiss mean std min max maxdec=1 data=import;
var Week--EffectiveRucks;
class Fwd1Bk2;
run;

ods noproctitle;
ods graphics / imagemap=on;

proc sort data=import;
by Fwd1Bk2;

title "Poisson regression with repeated measurement";
proc glimmix data=import plots=StudentPanel(conditional) nobound;
class AthleteID GameID;
model EffectiveRucks=MTPforceStdzd WeekRescaled
  /link=log dist=poisson offset=LnTimePlayed;
estimate "Mean" int 1/cl exp alpha=0.1;
estimate "";
estimate "Mean @ Week 1" int 1 WeekRescaled -0.5/cl exp alpha=0.1;
estimate "Mean @ Week 6" int 1 WeekRescaled 0.5/cl exp alpha=0.1;
estimate "Week 6/Week 1" WeekRescaled 1/cl exp alpha=0.1;
estimate "";
estimate "Mean @ -1SD MTPf" int 1 MTPforceStdzd -0.5/cl exp alpha=0.1;
estimate "Mean @ +1SD MTPf" int 1 MTPforceStdzd 0.5/cl exp alpha=0.1;
estimate "MTPf +1SD/-1SD" MTPforceStdzd 1/cl exp alpha=0.1;
random int/subject=AthleteID cl alpha=0.1;
random GameID;
random _residual_;
covtest/wald cl(alpha=0.1);
by Fwd1Bk2;
run;
*run the above again with nobound deleted for the Backs;

title "Poisson regression with repeated measurement";
title2 "MTPforceStdzd removed from the model";
proc glimmix data=import plots=StudentPanel(conditional);
class AthleteID GameID;
model EffectiveRucks=WeekRescaled
  /link=log dist=poisson offset=LnTimePlayed;
estimate "Mean" int 1/cl exp alpha=0.1;
estimate "";
estimate "Mean @ Week 1" int 1 WeekRescaled -0.5/cl exp alpha=0.1;
estimate "Mean @ Week 6" int 1 WeekRescaled 0.5/cl exp alpha=0.1;
estimate "Week 6/Week 1" WeekRescaled 1/cl exp alpha=0.1;
/*
estimate "";
estimate "Mean @ -1SD MTPf" int 1 MTPforceStdzd -0.5/cl exp alpha=0.1;
estimate "Mean @ +1SD MTPf" int 1 MTPforceStdzd 0.5/cl exp alpha=0.1;
estimate "MTPf +1SD/-1SD" MTPforceStdzd 1/cl exp alpha=0.1;
*/
random int/subject=AthleteID cl alpha=0.1;
random GameID;
random _residual_;
covtest/wald cl(alpha=0.1);
by Fwd1Bk2;
run;

title "Poisson regression with repeated measurement";
title2 "with Fwd2Bk2 in a reasonably complete model";
proc glimmix data=import plots=StudentPanel(conditional);
class AthleteID GameID Fwd1Bk2;
model EffectiveRucks=Fwd1Bk2 Fwd1Bk2*MTPforceStdzd WeekRescaled
  /link=log dist=poisson offset=LnTimePlayed;
lsmeans Fwd1Bk2/diff cl alpha=0.1 ilink;
estimate "Mean Fwds&Backs" int 1 Fwd1Bk2 0.5 0.5/cl exp alpha=0.1;
estimate "";
estimate "Mean Backs" int 1 Fwd1Bk2 0 1/cl exp alpha=0.1;
estimate "Mean Fwds" int 1 Fwd1Bk2 1 0/cl exp alpha=0.1;
estimate "Mean Fwds/Backs" Fwd1Bk2 1 -1/cl exp alpha=0.1;
estimate "";
estimate "Mean @ Week 1" int 1 WeekRescaled -0.5/cl exp alpha=0.1;
estimate "Mean @ Week 6" int 1 WeekRescaled 0.5/cl exp alpha=0.1;
estimate "Week 6/Week 1" WeekRescaled 1/cl exp alpha=0.1;
estimate "Backs:";
estimate "Mean @ -1SD MTPf" int 1 Fwd1Bk2 0 1 Fwd1Bk2*MTPforceStdzd 0 -0.5/cl exp alpha=0.1;
estimate "Mean @ +1SD MTPf" int 1 Fwd1Bk2 0 1 Fwd1Bk2*MTPforceStdzd 0 0.5/cl exp alpha=0.1;
estimate "MTPf +1SD/-1SD" Fwd1Bk2*MTPforceStdzd 0 1/cl exp alpha=0.1;
estimate "Fwds:";
estimate "Mean @ -1SD MTPf" int 1 Fwd1Bk2 1 0 Fwd1Bk2*MTPforceStdzd -0.5 0/cl exp alpha=0.1;
estimate "Mean @ +1SD MTPf" int 1 Fwd1Bk2 1 0 Fwd1Bk2*MTPforceStdzd 0.5 0/cl exp alpha=0.1;
estimate "MTPf +1SD/-1SD" Fwd1Bk2*MTPforceStdzd 1 0/cl exp alpha=0.1;
estimate "Backs/Fwds:";
estimate "Mean Backs+Fwds reference" int 1 Fwd1Bk2 0.5 0.5
  Fwd1Bk2*MTPforceStdzd -0.5 -0.5/cl exp alpha=0.1;
estimate "blank";
estimate "MTPf +1SD/-1SD" Fwd1Bk2*MTPforceStdzd -1 1/cl exp alpha=0.1;
random int/subject=AthleteID cl alpha=0.1;
random GameID;
random _residual_;
covtest/wald cl(alpha=0.1);
*by Fwd1Bk2;
run;


title "Logistic regression with repeated measurement";
proc glimmix data=import plots=StudentPanel(conditional) nobound;
class AthleteID GameID;
model EffectiveRucks/TotalRucks=MTPforceStdzd WeekRescaled
  /link=logit dist=binomial;
estimate "Mean" int 1/cl exp alpha=0.1;
estimate "";
estimate "Mean @ Week 1" int 1 WeekRescaled -0.5/cl exp alpha=0.1;
estimate "Mean @ Week 6" int 1 WeekRescaled 0.5/cl exp alpha=0.1;
estimate "Week 6/Week 1" WeekRescaled 1/cl exp alpha=0.1;
estimate "";
estimate "Mean @ -1SD MTPf" int 1 MTPforceStdzd -0.5/cl exp alpha=0.1;
estimate "Mean @ +1SD MTPf" int 1 MTPforceStdzd 0.5/cl exp alpha=0.1;
estimate "MTPf +1SD/-1SD" MTPforceStdzd 1/cl exp alpha=0.1;
random int/subject=AthleteID cl alpha=0.1;
random GameID;
random _residual_;
covtest/wald cl(alpha=0.1);
by Fwd1Bk2;
run;

title "Logistic regression with repeated measurement";
title2 "with Fwd2Bk2 in a reasonably complete model";
proc glimmix data=import plots=StudentPanel(conditional) nobound;
class AthleteID GameID Fwd1Bk2;
model EffectiveRucks/TotalRucks=Fwd1Bk2 Fwd1Bk2*MTPforceStdzd WeekRescaled
  /link=logit dist=binomial;
lsmeans Fwd1Bk2/diff cl alpha=0.1 ilink;
estimate "Mean Fwds&Backs" int 1 Fwd1Bk2 0.5 0.5/cl exp alpha=0.1;
estimate "";
estimate "Mean Backs" int 1 Fwd1Bk2 0 1/cl exp alpha=0.1;
estimate "Mean Fwds" int 1 Fwd1Bk2 1 0/cl exp alpha=0.1;
estimate "Mean Fwds/Backs" Fwd1Bk2 1 -1/cl exp alpha=0.1;
estimate "";
estimate "Mean @ Week 1" int 1 WeekRescaled -0.5/cl exp alpha=0.1;
estimate "Mean @ Week 6" int 1 WeekRescaled 0.5/cl exp alpha=0.1;
estimate "Week 6/Week 1" WeekRescaled 1/cl exp alpha=0.1;
estimate "Backs:";
estimate "Mean @ -1SD MTPf" int 1 Fwd1Bk2 0 1 Fwd1Bk2*MTPforceStdzd 0 -0.5/cl exp alpha=0.1;
estimate "Mean @ +1SD MTPf" int 1 Fwd1Bk2 0 1 Fwd1Bk2*MTPforceStdzd 0 0.5/cl exp alpha=0.1;
estimate "MTPf +1SD/-1SD" Fwd1Bk2*MTPforceStdzd 0 1/cl exp alpha=0.1;
estimate "Fwds:";
estimate "Mean @ -1SD MTPf" int 1 Fwd1Bk2 1 0 Fwd1Bk2*MTPforceStdzd -0.5 0/cl exp alpha=0.1;
estimate "Mean @ +1SD MTPf" int 1 Fwd1Bk2 1 0 Fwd1Bk2*MTPforceStdzd 0.5 0/cl exp alpha=0.1;
estimate "MTPf +1SD/-1SD" Fwd1Bk2*MTPforceStdzd 1 0/cl exp alpha=0.1;
estimate "Backs/Fwds:";
estimate "Mean Backs+Fwds reference" int 1 Fwd1Bk2 0.5 0.5
  Fwd1Bk2*MTPforceStdzd -0.5 -0.5/cl exp alpha=0.1;
estimate "blank";
estimate "MTPf +1SD/-1SD" Fwd1Bk2*MTPforceStdzd -1 1/cl exp alpha=0.1;
random int/subject=AthleteID cl alpha=0.1;
random GameID;
random _residual_;
covtest/wald cl(alpha=0.1);
*by Fwd1Bk2;
run;

